#!/bin/bash

# Script to inject AWIPS products into LDM
# Liam.Gumley@ssec.wisc.edu 28-MAY-2015

# Modified 22 SEPT 2017 to add site to product name
# Modified 14 DEC 2017 to update file size logic

# Set up log file
LOG=$HOME/awips/logs/$(date +%Y_%m_%d_%j)"_awips_inject.log" 
exec 1>> $LOG 
exec 2>> $LOG 

# Set up LDM
export LDMHOME=/home/ldm
export LDMPQ=$LDMHOME/var/queues
export LDMFEED=EXP
export GOOD_COMPRESSED_SIZE=150000
export GOOD_UNCOMPRESSED_SIZE=75000
export SITE=IRC

# Set local data directory
local_data=$HOME/awips/data

# List of DBPS directories to search for AWIPS products (separated by spaces)
export DATA=/home/dbvm/dbvm/data
dir_list="$DATA/eos/awips $DATA/gcom/awips $DATA/jpss/awips $DATA/metop/awips $DATA/noaa/awips"

# Scan each directory for new AWIPS product files (*_AII_*_Pacific_*)
for dir in $dir_list; do

  # Get list of AWIPS product files created in the last 120 minutes
  file_list=$(find $dir -type f -mmin -120 \( -name "*_AII_*_Pacific_*" ! -name "*gz*" \))
  echo $dir
  if [ $? -ne 0 ]; then
    echo "Failed to get list of AWIPS product files from directory "$dir
    exit 1
  fi

  # Check for non-null file list
  if [ -n "$file_list" ]; then

    # Loop over each AWIPS product file
    for awips_file in $file_list; do

      # Set local file name
      local_file=$(basename $awips_file)

      # If AWIPS file does not exist in local data directory, copy it and inject it
      if [ ! -e $local_data/$local_file ]; then

        # Copy the file
        rsync $awips_file $local_data

        # Make a compressed copy
        gzip -c $local_data/$local_file > $local_data/$local_file.gz

        # Check the compressed file size
        compressed_file_size=$(stat -c %s $local_data/$local_file.gz)

        # Check the uncompressed file size
        uncompressed_file_size=$(stat -c %s $local_data/$local_file)

        if [[ "$local_file" =~ "_204_" ]] ; then
           file_size=$compressed_file_size
           GOOD_SIZE=$GOOD_COMPRESSED_SIZE
        else
           file_size=$uncompressed_file_size
           GOOD_SIZE=$GOOD_UNCOMPRESSED_SIZE
        fi

        if [ $file_size -ge $GOOD_SIZE ]; then

          # Inject the compressed copy
          echo $(date -u) $LDMHOME/bin/pqinsert -f $LDMFEED -q $LDMPQ/ldm.pq -p $local_file.$SITE $local_data/$local_file.gz
          $LDMHOME/bin/pqinsert -f $LDMFEED -q $LDMPQ/ldm.pq -p $local_file.gz.$SITE $local_data/$local_file.gz
          if [ $? -ne 0 ]; then
            echo "Failed to inject file "$local_data/$local_file.gz
          else
            sleep 3s
          fi

        fi

        # Delete the compressed copy
        rm $local_data/$local_file.gz

      fi

    done

  fi

done

exit 0
